package cn.rankin.apiweb.service.product;

import cn.rankin.apiweb.code.ApiWebCode;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.data.api.product.entity.MerchantProduct;
import cn.rankin.data.api.product.entity.Recommend;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "${service.product.name}")
public interface ProductClient {

    @RequestMapping(value = "/recommend/courses", method = RequestMethod.GET)
    APIResult<List<Recommend>> getRecommendCourses(@RequestParam("merchantId") String merchantId);

    @RequestMapping(value = "/merchant/product/detail", method = RequestMethod.GET)
    APIResult<MerchantProduct> getProduct(@RequestParam("pid") String productId, @RequestParam("merchantId") String merchantId);

    @Component
    class ProductClientHystrix implements ProductClient {

        @Override
        public APIResult getRecommendCourses(String merchantId) {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public APIResult getProduct(String productId, String merchantId) {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }
    }
}
